@@ -4,7 +4,7 @@ use warnings;
 package CPAN::Meta::Requirements;
 # ABSTRACT: a set of version requirements for a CPAN dist
 
-our $VERSION = '2.142';
+our $VERSION = '2.144';
 
 use CPAN::Meta::Requirements::Range;
 
@@ -486,7 +486,7 @@ CPAN::Meta::Requirements - a set of version requirements for a CPAN dist
 
 =head1 VERSION
 
-version 2.142
+version 2.144
 
 =head1 SYNOPSIS
 
@@ -776,13 +776,13 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ed J Graham Knop Karen Etheridge Leon Timmermans Ricardo Signes robario Tatsuhiko Miyagawa
+=for stopwords Ed J Graham Knop Karen Etheridge Leon Timmermans Paul Howarth Philippe Bruhat (BooK) Ricardo Signes robario Tatsuhiko Miyagawa
 
 =over 4
 
@@ -804,6 +804,14 @@ Leon Timmermans <fawaka@gmail.com>
 
 =item *
 
+Paul Howarth <paul@city-fan.org>
+
+=item *
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
+=item *
+
 Ricardo Signes <rjbs@semiotic.systems>
 
 =item *
@@ -814,10 +822,6 @@ robario <webmaster@robario.com>
 
 Tatsuhiko Miyagawa <miyagawa@bulknews.net>
 
-=item *
-
-Tatsuhiko Miyagawa <miyagawa@gmail.com>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
