@@ -4,7 +4,7 @@ use warnings;
 package CPAN::Meta::Requirements::Range;
 # ABSTRACT: a set of version requirements for a CPAN dist
 
-our $VERSION = '2.142';
+our $VERSION = '2.144';
 
 use Carp ();
 
@@ -97,10 +97,6 @@ sub _version_object {
       my $magic = _find_magic_vstring( $version );
       $version = $magic if length $magic;
     }
-    # pad to 3 characters if before 5.8.1 and appears to be a v-string
-    if ( $] < 5.008001 && $version !~ /\A[0-9]/ && substr($version,0,1) ne 'v' && length($version) < 3 ) {
-      $version .= "\0" x (3 - length($version));
-    }
     eval {
       local $SIG{__WARN__} = sub { die "Invalid version: $_[0]" };
       # avoid specific segfault on some older version.pm versions
@@ -193,7 +189,7 @@ sub with_string_requirement {
     my ($op, $ver) = $part =~ m{\A\s*(==|>=|>|<=|<|!=)\s*(.*)\z};
 
     if (! defined $op) {
-      return $self->with_minimum($part, $module, $bad_version_hook);
+      $self = $self->with_minimum($part, $module, $bad_version_hook);
     } else {
       Carp::croak("illegal requirement string: $req")
         unless my $methods = $methods_for_op{ $op };
@@ -460,6 +456,7 @@ sub as_string {
   my @parts = @{ $self->as_struct };
 
   return $parts[0][1] if @parts == 1 and $parts[0][0] eq '>=';
+  @parts = grep { $_->[0] ne '>=' || $_->[1] != 0 } @parts;
 
   return join q{, }, map {; join q{ }, @$_ } @parts;
 }
@@ -607,7 +604,7 @@ CPAN::Meta::Requirements::Range - a set of version requirements for a CPAN dist
 
 =head1 VERSION
 
-version 2.142
+version 2.144
 
 =head1 SYNOPSIS
 
@@ -762,7 +759,7 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =back
 
